/*  
Phillip Neal modified quicktree to do only distances */
/***********************************************************************
 ** FILE: quickdist.c
 ** NOTES:
 **  This program does one of one things:
 ** 1. Given an aligment, construct a distance matrix.
 ** 
 ** Only 1 argument input pfam file of the alignment
 ** output goes to stdout
 
 ***********************************************************************/
/*
#include "options.h"
*/
#include "util.h"
#include "align.h"

#include "distancemat.h"

/********************* command-line options * ************************/

static char usage[] = "\
Usage: quickdist  [-t] <PFAM_inputfile> \n\
\n\tArguments must be in order \n \
\n\tOutput goes to stdout \n\
\n\tQuickdist computes pairwise distance of a PFAM formatted input file \n \
\tof nucleotides \n \
\nOptions:\n\
\tIf you add the -t option it means with terminal \n \
\tgaps removed at either end of a sequence \n \
\tNucleotides from the other sequence will be lopped off too \n ";


static unsigned int use_kimura = 0; 
/*
static unsigned int calc_bootstraps = 0;
static unsigned int use_upgma = 0;
static unsigned int input_is_matrix = 0;
*/

static unsigned int output_is_matrix = 0;

static void quickdist( FILE *input) {

struct Alignment *aln = NULL;

struct DistanceMatrix *mat;
  /* step 1: get the distance matrix (either build or read it) */

    /* input must be an alignment */

if ( ( aln = read_Stockholm_Alignment( input )) == NULL)
      fatal_util( "Parse error in alignment file: Must be in MUL format");
    fclose( input );
    
      mat = empty_DistanceMatrix( aln->numseqs );
      calc_DistanceMatrix( mat, aln, FALSE, use_kimura );
      write_phylip_DistanceMatrix( stdout, mat, aln );
      mat = free_DistanceMatrix( mat );
      return;

aln = free_Alignment( aln );

}



/*********************************************************************
		        MAIN
 *********************************************************************/

int main (int argc, char *argv[]) {

  FILE *input;
  char *fname;
  
output_is_matrix = 1;
term_gap_switch = 0;
fname = "";
if (argc == 2 )
{
	fname = argv[1];
}

else if(argc == 3)
{
	if(strcmp(argv[1],"-t") == 0)
	{
		term_gap_switch=1;
	}
	else
	{
    		fatal_util(
		"Fatal error: with 2 arguments , first must be a '-t'.\n%s\n", usage );
	}

	fname = argv[2];
}
else
{
    fatal_util("Fatal error: Incorrect number of arguments.\n%s\n", usage );
}

if ((input = fopen( fname, "r" )) == NULL)
    fatal_util( "Could not open file %s for reading", fname );

quickdist( input );

exit(0);
}
